package com.ruoyi.sensor.merchants;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.utils.http.HttpUtils;
import com.ruoyi.sensor.domain.PerceptionWarningStatusInfo;
import com.ruoyi.sensor.domain.ReleaseLogReport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class MerchantsHttp {
    private static final Logger log = LoggerFactory.getLogger(MerchantsHttp.class);

    private static String STATUS_URI;
    private static String PUBLICATION_LOG_URI;

    @Value("${remote.statusReport}")
    public void setStatusUri(String statusUri) {
        STATUS_URI = statusUri;
    }

    @Value("${remote.logReport}")
    public void setPublicationLogUri(String publicationLogUri) {
        PUBLICATION_LOG_URI = publicationLogUri;
    }

    public static void sendWarningStatus(PerceptionWarningStatusInfo perceptionWarningStatusInfo){
        String jsonString = JSON.toJSONString(perceptionWarningStatusInfo);
        send(STATUS_URI, jsonString);
    }

    public static void sendPublicationLog(ReleaseLogReport releaseLogReport){
        String jsonString = JSON.toJSONString(releaseLogReport);
        send(PUBLICATION_LOG_URI, jsonString);

    }

    private static void send(String URI, String jsonStr) {
        String result = null;
        try {
            result = HttpUtils.postCall(URI, jsonStr);
        } catch (Exception e) {
            log.error("send warning error", e);
            return;
        }
        if (StringUtils.isEmpty(result)) {
            log.error("发送信息成功，但是没有接收到响应信息");
        } else {
            log.info(result);
        }
    }
}
